# Analysis Plugins

* [browser_search](Analysis-plugin-browser-search.md): Analyze browser search entries from events.
* [chrome_extension](Analysis-plugin-chrome-extension.md): Analysis plugin to gather information about Chrome extensions.
* [bloom](Analysis-plugin-bloom.md): Analysis plugin for looking up hashes in a bloom file.
* [nsrlsvr](Analysis-plugin-nsrlsvr.md): Analysis plugin for looking up hashes in nsrlsvr.
* [sessionize](Analysis-plugin-sessionize.md): Analysis plugin that labels events by session.
* [tagging](Analysis-plugin-tagging.md): Analysis plugin that labels events according to rules in a tagging file.
* [unique_domains_visited](Analysis-plugin-unique-domains-visited.md): A plugin to generate a list all domains visited.
* [viper](Analysis-plugin-viper.md): An analysis plugin for looking up SHA256 hashes in Viper.
* [virustotal](Analysis-plugin-virustotal.md): An analysis plugin for looking up hashes in VirusTotal.
